<?php

namespace Cabag\SqlScheduler\Task;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2016 Tizian Schmidlin <st@cabag.ch>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

class SqlSchedulerTaskAdditionalFieldProvider implements \TYPO3\CMS\Scheduler\AdditionalFieldProviderInterface {

	/**
	 * Gets additional fields to render in the form to add/edit a task
	 *
	 * @param array $taskInfo Values of the fields from the add/edit task form
	 * @param \TYPO3\CMS\Scheduler\Task\AbstractTask $task The task object being
	 *        	edited. Null when adding a task!
	 * @param \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $schedulerModule
	 *        	Reference to the scheduler backend module
	 * @return array A two dimensional array, array('Identifier' =>
	 *         array('fieldId' => array('code' => '', 'label' => '', 'cshKey' =>
	 *         '', 'cshLabel' => ''))
	 */
	public function getAdditionalFields(array &$taskInfo, $task, \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $parentObject) {

		// Initialize extra field value
		if (empty($taskInfo['sqlquery'])) {
			if ($parentObject->CMD == 'edit') {
				// In case of edit, and editing a test task, set to internal
				// value if not data was submitted already
				$taskInfo['sqlquery'] = $task->sqlquery;
			} else {
				// Otherwise set an empty value, as it will not be used anyway
				$taskInfo['sqlquery'] = '';
			}
		}
		// Write the code for the field
		$fieldID = 'task_sqlquery';
		$fieldCode = '<input type="text" name="tx_scheduler[sqlquery]" id="' . $fieldID . '" value="' . htmlspecialchars($taskInfo['sqlquery']) . '" size="30" />';
		$additionalFields = array();
		$additionalFields[$fieldID] = array(
				'code' => $fieldCode,
				'label' => 'SQL Query',
				'cshKey' => '_MOD_system_txschedulerM1',
				'cshLabel' => $fieldID
		);

		return $additionalFields;
	}

	/**
	 * Validates the additional fields' values
	 *
	 * @param array $submittedData An array containing the data submitted by the
	 *        	add/edit task form
	 * @param \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $schedulerModule
	 *        	Reference to the scheduler backend module
	 * @return boolean TRUE if validation was ok (or selected class is not
	 *         relevant), FALSE otherwise
	 */
	public function validateAdditionalFields(array &$submittedData, \TYPO3\CMS\Scheduler\Controller\SchedulerModuleController $parentObject) {
		$submittedData['sqlquery'] = trim($submittedData['sqlquery']);
		if (empty($submittedData['sqlquery'])) {
			$parentObject->addMessage($GLOBALS['LANG']->sL('LLL:EXT:nabhomeis24/Resources/Private/Language/locallang.xlf:tx_nabhomeis24_xml_export_app_noFilePath'), \TYPO3\CMS\Core\Messaging\FlashMessage::ERROR);
			return FALSE;
		}
		return TRUE;
	}

	/**
	 * Takes care of saving the additional fields' values in the task's object
	 *
	 * @param array $submittedData An array containing the data submitted by the
	 *        	add/edit task form
	 * @param \TYPO3\CMS\Scheduler\Task\AbstractTask $task Reference to the
	 *        	scheduler backend module
	 * @return void
	 */
	public function saveAdditionalFields(array $submittedData, \TYPO3\CMS\Scheduler\Task\AbstractTask $task) {
		$task->setSqlquery($submittedData['sqlquery']);
	}
}
